@@ -400,6 +400,7 @@ class TestIntervalStats(unittest.TestCase):
         i1.out_octets = 0
         l1 = i1.links.add()
         l1.mac_address = '0b:00:01:00:00:01'
+        l1.poller_hash = _make_poller_hash(company_uuid, l1.mac_address)
         l1.in_octets = 1000
         new_msg = self.mgr.handle_message(msg, 'idA')
         self.assertIsNone(new_msg)
@@ -432,6 +433,7 @@ class TestIntervalStats(unittest.TestCase):
         msg4.data.interfaces[0].links[0].in_octets += 30
         l2 = msg4.data.interfaces[0].links.add()
         l2.mac_address = '0b:00:01:00:00:02'
+        l2.poller_hash = _make_poller_hash(company_uuid, l2.mac_address)
         l2.in_octets = 1000
         new_msg = self.mgr.handle_message(msg4, 'idA')
         self.assertIsNone(new_msg)
@@ -475,6 +477,7 @@ class TestIntervalStats(unittest.TestCase):
         i1 = msg.data.interfaces.add()
         i1.id = '1'
         i1.name = 'WLAN'
+        i1.poller_hash = _make_poller_hash(company_uuid, i1.id)
         i1.in_octets = 10000
         i1.in_errors = 0
 
@@ -518,6 +521,7 @@ class TestIntervalStats(unittest.TestCase):
         i2 = msg4.data.interfaces.add()
         i2.id = '2'
         i2.name = 'LAN1'
+        i2.poller_hash = _make_poller_hash(company_uuid, i2.id)
         i2.in_octets = 10000
         i2.in_errors = 0
         new_msg = self.mgr.handle_message(msg4)
